@@ -378,7 +378,6 @@ g_tls_certificate_gnutls_real_copy (GTlsCertificateGnutls    *gnutls,
 {
   GTlsCertificateGnutls *chain;
   guint num_certs = 0;
-  size_t size = 0;
   int status;
 
   /* We will do this loop twice. It's probably more efficient than
@@ -393,9 +392,7 @@ g_tls_certificate_gnutls_real_copy (GTlsCertificateGnutls    *gnutls,
     }
 
   *pcert_length = 0;
-  *pcert = gnutls_malloc (sizeof (gnutls_pcert_st) * num_certs);
-  if (*pcert == NULL)
-    g_error ("%s: out of memory", __FUNCTION__);
+  *pcert = g_malloc (sizeof (gnutls_pcert_st) * num_certs);
 
   /* Now do the actual copy of the whole chain. */
   chain = gnutls;
@@ -405,17 +402,12 @@ g_tls_certificate_gnutls_real_copy (GTlsCertificateGnutls    *gnutls,
       gnutls_x509_crt_t cert;
       gnutls_datum_t data;
 
-      gnutls_x509_crt_export (priv->cert, GNUTLS_X509_FMT_DER,
-                              NULL, &size);
-      data.data = g_malloc (size);
-      data.size = size;
-      gnutls_x509_crt_export (priv->cert, GNUTLS_X509_FMT_DER,
-                              data.data, &size);
+      gnutls_x509_crt_export2 (priv->cert, GNUTLS_X509_FMT_DER, &data);
 
       gnutls_x509_crt_init (&cert);
       status = gnutls_x509_crt_import (cert, &data, GNUTLS_X509_FMT_DER);
       g_warn_if_fail (status == 0);
-      g_free (data.data);
+      gnutls_free (data.data);
 
       gnutls_pcert_import_x509 (*pcert + *pcert_length, cert, 0);
       gnutls_x509_crt_deinit (cert);
@@ -538,6 +530,22 @@ g_tls_certificate_gnutls_copy  (GTlsCertificateGnutls  *gnutls,
                                                      pkey);
 }
 
+void
+g_tls_certificate_gnutls_copy_free (gnutls_pcert_st  *pcert,
+                                    unsigned int      pcert_length,
+                                    gnutls_privkey_t  pkey)
+{
+  if (pcert != NULL)
+    {
+      for (unsigned int i = 0; i < pcert_length; i++)
+        gnutls_pcert_deinit (&pcert[i]);
+      g_free (pcert);
+    }
+
+  if (pkey != NULL)
+    gnutls_privkey_deinit (pkey);
+}
+
 static const struct {
   int gnutls_flag;
   GTlsCertificateFlags gtls_flag;
