@@ -41,6 +41,11 @@
 #include "pkcs11/gpkcs11util.h"
 #include "pkcs11/pkcs11-trust-assertions.h"
 
+typedef enum {
+  G_TLS_DATABASE_GNUTLS_PINNED_CERTIFICATE = 1,
+  G_TLS_DATABASE_GNUTLS_ANCHORED_CERTIFICATE = 2,
+} GTlsDatabaseGnutlsAssertion;
+
 static const CK_ATTRIBUTE_TYPE CERTIFICATE_ATTRIBUTE_TYPES[] = {
     CKA_ID, CKA_LABEL, CKA_CLASS, CKA_VALUE
 };
@@ -53,7 +58,7 @@ static void g_tls_database_gnutls_pkcs11_initable_iface_init (GInitableIface *if
 
 struct _GTlsDatabaseGnutlsPkcs11
 {
-  GTlsDatabaseGnutls parent_instance;
+  GTlsDatabase parent_instance;
 
   /* no changes after construction */
   CK_FUNCTION_LIST **modules;
@@ -62,7 +67,7 @@ struct _GTlsDatabaseGnutlsPkcs11
 };
 
 G_DEFINE_TYPE_WITH_CODE (GTlsDatabaseGnutlsPkcs11, g_tls_database_gnutls_pkcs11,
-                         G_TYPE_TLS_DATABASE_GNUTLS,
+                         G_TYPE_TLS_DATABASE,
                          G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
                                                 g_tls_database_gnutls_pkcs11_initable_iface_init));
 
@@ -1039,7 +1044,7 @@ g_tls_database_gnutls_pkcs11_verify_chain (GTlsDatabase             *database,
 
   gerr = gnutls_x509_crt_list_verify (certs, certs_length,
                                       anchors, anchors_length,
-                                      NULL, 0, GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT,
+                                      NULL, 0, 0,
                                       &gnutls_result);
 
   g_free (certs);
